[SCM] WebKit Debian packaging branch, debian/experimental, updated. upstream/1.3.3-9427-gc2be6fc

hyatt at apple.com hyatt at apple.com
Wed Dec 22 14:20:01 UTC 2010


The following commit has been merged in the debian/experimental branch:
commit a956e33316dfc7f9ede16b3549107d2c77f1734c
Author: hyatt at apple.com <hyatt at apple.com@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Wed Oct 6 20:35:21 2010 +0000

    https://bugs.webkit.org/show_bug.cgi?id=47298
    
    Reviewed by Dan Bernstein.
    
    Rename blockHeight to blockLogicalHeight.
    
    * rendering/RenderBlock.cpp:
    (WebCore::RenderBlock::markLinesDirtyInBlockRange):
    * rendering/RenderBlockLineLayout.cpp:
    (WebCore::RenderBlock::computeBlockDirectionPositionsForLine):
    (WebCore::RenderBlock::layoutInlineChildren):
    (WebCore::RenderBlock::determineStartPosition):
    (WebCore::RenderBlock::determineEndPosition):
    (WebCore::RenderBlock::matchedEndLine):
    * rendering/RootInlineBox.cpp:
    (WebCore::RootInlineBox::RootInlineBox):
    (WebCore::RootInlineBox::adjustPosition):
    * rendering/RootInlineBox.h:
    (WebCore::RootInlineBox::blockLogicalHeight):
    (WebCore::RootInlineBox::setBlockLogicalHeight):
    * rendering/svg/SVGRootInlineBox.cpp:
    (WebCore::SVGRootInlineBox::layoutRootBox):
    
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@69228 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/ChangeLog b/WebCore/ChangeLog
index 887df56..3159159 100644
--- a/WebCore/ChangeLog
+++ b/WebCore/ChangeLog
@@ -1,3 +1,28 @@
+2010-10-06  David Hyatt  <hyatt at apple.com>
+
+        Reviewed by Dan Bernstein.
+
+        https://bugs.webkit.org/show_bug.cgi?id=47298
+        
+        Rename blockHeight to blockLogicalHeight.
+
+        * rendering/RenderBlock.cpp:
+        (WebCore::RenderBlock::markLinesDirtyInBlockRange):
+        * rendering/RenderBlockLineLayout.cpp:
+        (WebCore::RenderBlock::computeBlockDirectionPositionsForLine):
+        (WebCore::RenderBlock::layoutInlineChildren):
+        (WebCore::RenderBlock::determineStartPosition):
+        (WebCore::RenderBlock::determineEndPosition):
+        (WebCore::RenderBlock::matchedEndLine):
+        * rendering/RootInlineBox.cpp:
+        (WebCore::RootInlineBox::RootInlineBox):
+        (WebCore::RootInlineBox::adjustPosition):
+        * rendering/RootInlineBox.h:
+        (WebCore::RootInlineBox::blockLogicalHeight):
+        (WebCore::RootInlineBox::setBlockLogicalHeight):
+        * rendering/svg/SVGRootInlineBox.cpp:
+        (WebCore::SVGRootInlineBox::layoutRootBox):
+
 2010-10-05  James Robinson  <jamesr at chromium.org>
 
         Reviewed by Kenneth Russell.
diff --git a/WebCore/rendering/RenderBlock.cpp b/WebCore/rendering/RenderBlock.cpp
index 63288a7..2bf72d9 100644
--- a/WebCore/rendering/RenderBlock.cpp
+++ b/WebCore/rendering/RenderBlock.cpp
@@ -3606,12 +3606,12 @@ void RenderBlock::markLinesDirtyInBlockRange(int logicalTop, int logicalBottom,
 
     RootInlineBox* lowestDirtyLine = lastRootBox();
     RootInlineBox* afterLowest = lowestDirtyLine;
-    while (lowestDirtyLine && lowestDirtyLine->blockHeight() >= logicalBottom) {
+    while (lowestDirtyLine && lowestDirtyLine->blockLogicalHeight() >= logicalBottom) {
         afterLowest = lowestDirtyLine;
         lowestDirtyLine = lowestDirtyLine->prevRootBox();
     }
 
-    while (afterLowest && afterLowest != highest && afterLowest->blockHeight() >= logicalTop) {
+    while (afterLowest && afterLowest != highest && afterLowest->blockLogicalHeight() >= logicalTop) {
         afterLowest->markDirty();
         afterLowest = afterLowest->prevRootBox();
     }
diff --git a/WebCore/rendering/RenderBlockLineLayout.cpp b/WebCore/rendering/RenderBlockLineLayout.cpp
index 9a9d0ba..0fd6ae6 100644
--- a/WebCore/rendering/RenderBlockLineLayout.cpp
+++ b/WebCore/rendering/RenderBlockLineLayout.cpp
@@ -464,7 +464,7 @@ void RenderBlock::computeInlineDirectionPositionsForLine(RootInlineBox* lineBox,
 void RenderBlock::computeBlockDirectionPositionsForLine(RootInlineBox* lineBox, BidiRun* firstRun, GlyphOverflowAndFallbackFontsMap& textBoxDataMap)
 {
     setLogicalHeight(lineBox->alignBoxesInBlockDirection(height(), textBoxDataMap));
-    lineBox->setBlockHeight(height());
+    lineBox->setBlockLogicalHeight(height());
 
     // Now make sure we place replaced render objects correctly.
     for (BidiRun* r = firstRun; r; r = r->next()) {
@@ -790,7 +790,7 @@ void RenderBlock::layoutInlineChildren(bool relayoutChildren, int& repaintTop, i
                                 continue;
                             }
 
-                            setLogicalHeight(lineBox->blockHeight());
+                            setLogicalHeight(lineBox->blockLogicalHeight());
                         }
                     }
                 }
@@ -846,7 +846,7 @@ void RenderBlock::layoutInlineChildren(bool relayoutChildren, int& repaintTop, i
                         }
                     }
                 }
-                setLogicalHeight(lastRootBox()->blockHeight());
+                setLogicalHeight(lastRootBox()->blockLogicalHeight());
             } else {
                 // Delete all the remaining lines.
                 RootInlineBox* line = endLine;
@@ -873,7 +873,7 @@ void RenderBlock::layoutInlineChildren(bool relayoutChildren, int& repaintTop, i
                 GlyphOverflowAndFallbackFontsMap textBoxDataMap;
                 trailingFloatsLineBox->alignBoxesInBlockDirection(height(), textBoxDataMap);
                 trailingFloatsLineBox->setBlockDirectionOverflowPositions(height(), bottomLayoutOverflow, height(), bottomVisualOverflow, 0);
-                trailingFloatsLineBox->setBlockHeight(height());
+                trailingFloatsLineBox->setBlockLogicalHeight(height());
             }
             if (lastFloat) {
                 for (FloatingObject* f = m_floatingObjects->last(); f != lastFloat; f = m_floatingObjects->prev()) {
@@ -959,7 +959,7 @@ RootInlineBox* RenderBlock::determineStartPosition(bool& firstLine, bool& fullLa
                     if (floats[floatIndex].rect.size() != newSize) {
                         int floatTop = floats[floatIndex].rect.y();
                         curr->markDirty();
-                        markLinesDirtyInBlockRange(curr->blockHeight(), floatTop + max(floats[floatIndex].rect.height(), newSize.height()), curr);
+                        markLinesDirtyInBlockRange(curr->blockLogicalHeight(), floatTop + max(floats[floatIndex].rect.height(), newSize.height()), curr);
                         floats[floatIndex].rect.setSize(newSize);
                         dirtiedByFloat = true;
                     }
@@ -1034,7 +1034,7 @@ RootInlineBox* RenderBlock::determineStartPosition(bool& firstLine, bool& fullLa
     RenderObject* startObj;
     int pos = 0;
     if (last) {
-        setLogicalHeight(last->blockHeight());
+        setLogicalHeight(last->blockLogicalHeight());
         startObj = last->lineBreakObj();
         pos = last->lineBreakPos();
         resolver.setStatus(last->lineBreakBidiStatus());
@@ -1079,7 +1079,7 @@ RootInlineBox* RenderBlock::determineEndPosition(RootInlineBox* startLine, Inlin
     RootInlineBox* prev = last->prevRootBox();
     cleanLineStart = InlineIterator(this, prev->lineBreakObj(), prev->lineBreakPos());
     cleanLineBidiStatus = prev->lineBreakBidiStatus();
-    yPos = prev->blockHeight();
+    yPos = prev->blockLogicalHeight();
 
     for (RootInlineBox* line = last; line; line = line->nextRootBox())
         line->extractLine(); // Disconnect all line boxes from their render objects while preserving
@@ -1105,7 +1105,7 @@ bool RenderBlock::matchedEndLine(const InlineBidiResolver& resolver, const Inlin
         while (RootInlineBox* nextLine = lastLine->nextRootBox())
             lastLine = nextLine;
 
-        int bottom = lastLine->blockHeight() + abs(delta);
+        int bottom = lastLine->blockLogicalHeight() + abs(delta);
 
         for (FloatingObject* f = m_floatingObjects->first(); f; f = m_floatingObjects->next()) {
             if (f->bottom() >= top && f->bottom() < bottom)
@@ -1128,7 +1128,7 @@ bool RenderBlock::matchedEndLine(const InlineBidiResolver& resolver, const Inlin
 
             // Set our yPos to be the block height of endLine.
             if (result)
-                endYPos = line->blockHeight();
+                endYPos = line->blockLogicalHeight();
 
             int delta = height() - endYPos;
             if (delta && m_floatingObjects) {
@@ -1139,7 +1139,7 @@ bool RenderBlock::matchedEndLine(const InlineBidiResolver& resolver, const Inlin
                 while (RootInlineBox* nextLine = lastLine->nextRootBox())
                     lastLine = nextLine;
 
-                int bottom = lastLine->blockHeight() + abs(delta);
+                int bottom = lastLine->blockLogicalHeight() + abs(delta);
 
                 for (FloatingObject* f = m_floatingObjects->first(); f; f = m_floatingObjects->next()) {
                     if (f->bottom() >= top && f->bottom() < bottom)
diff --git a/WebCore/rendering/RootInlineBox.cpp b/WebCore/rendering/RootInlineBox.cpp
index 3be9994..38aba23 100644
--- a/WebCore/rendering/RootInlineBox.cpp
+++ b/WebCore/rendering/RootInlineBox.cpp
@@ -46,6 +46,7 @@ RootInlineBox::RootInlineBox(RenderBlock* block)
     , m_lineTop(0)
     , m_lineBottom(0)
     , m_paginationStrut(0)
+    , m_blockLogicalHeight(0)
 {
     setIsVertical(!block->style()->isHorizontalWritingMode());
 }
@@ -199,7 +200,7 @@ void RootInlineBox::adjustPosition(int dx, int dy)
     InlineFlowBox::adjustPosition(dx, dy);
     m_lineTop += dy;
     m_lineBottom += dy;
-    m_blockHeight += dy;
+    m_blockLogicalHeight += dy;
 }
 
 void RootInlineBox::childRemoved(InlineBox* box)
diff --git a/WebCore/rendering/svg/SVGRootInlineBox.cpp b/WebCore/rendering/svg/SVGRootInlineBox.cpp
index 9a54f10..7109e1f 100644
--- a/WebCore/rendering/svg/SVGRootInlineBox.cpp
+++ b/WebCore/rendering/svg/SVGRootInlineBox.cpp
@@ -189,7 +189,7 @@ void SVGRootInlineBox::layoutRootBox()
     setY(0);
     setLogicalWidth(widthBlock);
     setLogicalHeight(heightBlock);
-    setBlockHeight(heightBlock);
+    setBlockLogicalHeight(heightBlock);
     setLineTopBottomPositions(0, heightBlock);
 }
 

diff --git a/WebCore/rendering/RootInlineBox.h b/WebCore/rendering/RootInlineBox.h
index 8c75072..3f64b45 100644
--- a/WebCore/rendering/RootInlineBox.h
+++ b/WebCore/rendering/RootInlineBox.h
@@ -69,8 +69,8 @@ public:
     unsigned lineBreakPos() const { return m_lineBreakPos; }
     void setLineBreakPos(unsigned p) { m_lineBreakPos = p; }
 
-    int blockHeight() const { return m_blockHeight; }
-    void setBlockHeight(int h) { m_blockHeight = h; }
+    int blockLogicalHeight() const { return m_blockLogicalHeight; }
+    void setBlockLogicalHeight(int h) { m_blockLogicalHeight = h; }
 
     bool endsWithBreak() const { return m_endsWithBreak; }
     void setEndsWithBreak(bool b) { m_endsWithBreak = b; }
@@ -143,8 +143,8 @@ private:
     // good for as long as the line has not been marked dirty.
     OwnPtr<Vector<RenderBox*> > m_floats;
 
-    // The height of the block at the end of this line.  This is where the next line starts.
-    int m_blockHeight;
+    // The logical height of the block at the end of this line.  This is where the next line starts.
+    int m_blockLogicalHeight;
 
     WTF::Unicode::Direction m_lineBreakBidiStatusEor : 5;
     WTF::Unicode::Direction m_lineBreakBidiStatusLastStrong : 5;
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list